@@ -12,4 +12,17 @@ from playwright_recaptcha.recaptchav2.sync_solver import SyncSolver as SyncSolve
 from playwright_recaptcha.recaptchav3.async_solver import AsyncSolver as AsyncSolverV3
 from playwright_recaptcha.recaptchav3.sync_solver import SyncSolver as SyncSolverV3
 
-__version__ = "0.0.3"
+__all__ = [
+    "RecaptchaError",
+    "RecaptchaNotFoundError",
+    "RecaptchaRateLimitError",
+    "RecaptchaSolveError",
+    "RecaptchaTimeoutError",
+    "RecaptchaVersionError",
+    "AsyncSolverV2",
+    "SyncSolverV2",
+    "AsyncSolverV3",
+    "SyncSolverV3",
+]
+
+__version__ = "0.0.4"
